@@ -169,9 +169,16 @@ class Recipe(object):
                     '--no-ri',
                     '--bindir=%s' % bindir,
                 ]),
-            'GEMS': ' '.join(self.gems)
         }
-        self.run('%(GEM)s install %(OPTIONS)s %(GEMS)s' % s, self._get_env())
+        for gemname in self.gems:
+            if '==' in gemname:
+                gemname, version = gemname.split('==', 1)
+                s['GEMNAME'] = gemname.strip()
+                s['OPTIONS'] += ' --version %s' % version.strip()
+            else:
+                s['GEMNAME'] = gemname
+            self.run('%(GEM)s install %(OPTIONS)s %(GEMNAME)s' % s,
+                     self._get_env())
 
         for executable in os.listdir(bindir):
             installed_path = self._install_executable(
